==> carbon-component-mapper-3.22.0.tgz: package/esm/plain-text/plain-text.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "element", "component"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';

var PlainText = function PlainText(_ref) {
  var label = _ref.label,
      element = _ref.element,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, _excluded);

  return label.split('\n').map(function (paragraph, index) {
    return /*#__PURE__*/React.createElement(element, _objectSpread({
      key: index
    }, rest), paragraph);
  });
};

PlainText.propTypes = {
  label: PropTypes.string,
  element: PropTypes.string,
  component: PropTypes.string
};
PlainText.defaultProps = {
  element: 'p'
};
export default PlainText;

==> carbon-component-mapper-3.23.3.tgz: package/esm/plain-text/plain-text.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "element", "component"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';

var PlainText = function PlainText(_ref) {
  var label = _ref.label,
      _ref$element = _ref.element,
      element = _ref$element === void 0 ? 'p' : _ref$element,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, _excluded);

  return label.split('\n').map(function (paragraph, index) {
    return /*#__PURE__*/React.createElement(element, _objectSpread({
      key: index
    }, rest), paragraph);
  });
};

PlainText.propTypes = {
  label: PropTypes.string,
  element: PropTypes.string,
  component: PropTypes.string
};
export default PlainText;
